@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.2.1",
-        meson_version="1.4.1",
+        contourpy_version="1.3.0",
+        meson_version="1.5.1",
         mesonpy_version="0.16.0",
-        pybind11_version="2.12.0",
+        pybind11_version="2.13.5",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-usm51iqi/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy-1.2.1/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-kodh_s48/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-usm51iqi/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-kodh_s48/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
